Assign Epoch Start Time
assign_epoch_start_time(gps_data, epoch_length)A data frame of GPS data with an additional column indicating epoch start time
A data frame with GPS data including a column of timestamps and columns for latitude and longitude
The duration of an epoch in seconds
Selects the closest 30 second increment to assign epoch start time and takes the GPS coordinates associated with the latest time if there are multiple GPS data points in a given 30 second increment. This function returns a data frame of GPS data with a column of epoch times.