This function generates a data frame containing GPS data for a walking activity in Seattle, WA on April 7th, 2012. It calls the function generate_gps_data to create a series of GPS locations and speeds. The resulting data frame has columns for time, latitude, longitude, and speed.
generate_walking_in_seattle_gps_data(start_lat, start_long, start_time)A data frame with columns time, latitude, longitude, speed
The starting latitude of the walk.
The starting longitude of the walk.
The start time of a series of data