This function generates a list of activity epochs with specified minimum active counts per epoch, minimum bout length, maximum number of consecutive inactive epochs in a bout, minimum non-wearing length, and minimum complete day length.
make_active_period(
length = 1,
is_bout = TRUE,
non_wearing = FALSE,
complete_day = FALSE
)A list of activity epochs
Length of the active period
Logical indicating if the active period is a bout
Logical indicating if the active period is a non-wearing period
Logical indicating if the active period is a complete day