Learn R Programming

walkboutr (version 0.6.0)

make_full_walk_bout_df: Create a data frame of walking bouts with GPS data

Description

This function combines accelerometer and GPS data to create a data frame of walking bouts. It generates a full day of activity with bouts of minimum and non-bout periods, and GPS data for walking in Seattle. The accelerometer data is processed into bouts using the process_accelerometry_counts_into_bouts function. The GPS data is processed into epochs using the process_gps_data_into_gps_epochs function.

Usage

make_full_walk_bout_df()

Arguments

Value

A data frame of walking bouts with GPS data

Examples

Run this code
make_full_walk_bout_df()

Run the code above in your browser using DataLab