This function creates an inactive period with a given length.
make_inactive_period(
length = 1,
is_bout = FALSE,
non_wearing = FALSE,
complete_day = FALSE
)A data frame with columns activity_counts, bout, non_wearing, and complete_day, where activity_counts is set to 0 for the entire length, and bout, non_wearing, and complete_day are set according to the input values.
The length of the inactive period.
Logical value indicating whether this period is part of a bout of inactivity.
Logical value indicating whether this period is due to non-wearing of the accelerometer.
Logical value indicating whether this period occurs during a complete day of wearing the accelerometer.