make_non_bout_window: Create a non-bout window
Description
This function creates a non-bout window, which is a period of inactivity that is not long enough to be considered as an inactive bout.
Usage
make_non_bout_window(maximum_number_consec_inactive_epochs_in_bout = 3)
Value
a data frame with columns "activity_counts", "bout", "non_wearing", "complete_day"
Arguments
- maximum_number_consec_inactive_epochs_in_bout
maximum number of consecutive inactive epochs in a bout before it is terminated