Learn R Programming

walkboutr (version 0.6.0)

make_smallest_bout: Make the smallest bout dataset

Description

Generates a dataset representing the smallest bout, consisting of a sequence of inactive periods followed by the smallest active period.

Usage

make_smallest_bout()

Arguments

Value

A data frame containing the activity counts and bout information for the smallest bout.

Examples

Run this code
make_smallest_bout()

Run the code above in your browser using DataLab