This function creates an active period of minimum length defined by the parameter minimum_bout_length.
make_smallest_bout_window(
minimum_bout_length = 10,
is_bout = TRUE,
non_wearing = FALSE,
complete_day = FALSE
)A data.frame with columns activity_counts, bout, non_wearing, and complete_day representing the smallest bout window.
is the minimum number of epochs for something to be considered a bout
Logical indicating if the active period is a bout
Logical indicating if the active period is a non-wearing period
Logical indicating if the active period is a complete day