make_smallest_bout_with_largest_inactive_period: Generate a sequence of accelerometer counts representing the smallest bout with the largest inactive period
Description
This function generates a sequence of accelerometer counts representing the smallest bout with the largest inactive period.
The length of the inactive period is determined by the value of maximum_number_consec_inactive_epochs_in_bout variable.