Learn R Programming

walkboutr (version 0.6.0)

make_smallest_bout_without_metadata: Create the smallest bout window without metadata

Description

This function creates the smallest bout window without the metadata columns. It calls the make_smallest_bout function and then removes the columns "non_wearing", "complete_day", and "bout" using dplyr::select.

Usage

make_smallest_bout_without_metadata()

Arguments

Value

A data frame containing the smallest bout window without metadata.

Examples

Run this code
make_smallest_bout_without_metadata()

Run the code above in your browser using DataLab