Learn R Programming

walkboutr (version 0.6.0)

make_smallest_complete_day_activity: Generate an activity sequence for a complete day with minimal activity

Description

This function generates an activity sequence for a complete day with a minimal activity count.

Usage

make_smallest_complete_day_activity(min_complete_day = 8602)

Value

An activity sequence data frame with minimum activity counts for a complete day.

Arguments

min_complete_day

minimum number of epochs for something to be a complete day

Examples

Run this code
make_smallest_complete_day_activity()

Run the code above in your browser using DataLab