Learn R Programming

walkboutr (version 0.6.0)

outlier_gps_points: Outlier GPS data points This function identifies outlier GPS points for the bout radius calculation from a given set of latitude and longitude coordinates.

Description

Outlier GPS data points This function identifies outlier GPS points for the bout radius calculation from a given set of latitude and longitude coordinates.

Usage

outlier_gps_points(lat_long, dwellbout_radii_quantile)

Value

A data frame containing the latitude and longitude coordinates for the non-outlier GPS points.

Arguments

lat_long

A data frame containing the latitude and longitude coordinates for the GPS points.

dwellbout_radii_quantile

The threshold for outliering GPS data points - any data points above the specified percentile are outliered.