| parameters | R Documentation |
List of Parameters
epoch_length The duration of an epoch in seconds.
active_counts_per_epoch_min Minimum accelerometer counts for an epoch to be considered active (vs. inactive).
minimum_bout_length Minimum number of epochs for a period of activity to be considered as a potential bout.
local_time_zone Local time zone of the data - data come in and are returned in UTC, but local time zone is used to compute complete_days.
maximum_number_consec_inactive_epochs_in_bout Number of consecutive epochs that can be labeled as inactive during a bout without ending the bout.
parameters
An object of class list of length 5.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.