Learn R Programming

walkboutr (version 0.6.0)

summarize_walk_bouts: Summarize walking bouts: This function summarizes walking bouts and calculates the median speed, complete day, non-wearing, bout start, and duration of each bout.

Description

Summarize walking bouts: This function summarizes walking bouts and calculates the median speed, complete day, non-wearing, bout start, and duration of each bout.

Usage

summarize_walk_bouts(walk_bouts, ..., collated_arguments = NULL)

Value

A data frame summarizing identified walk bouts

Arguments

walk_bouts

A data frame containing identified walk bouts

...

Additional arguments to be passed to the function

collated_arguments

A list of collated arguments