add_date_and_format: Add date and format to activity counts
Description
This function takes a data frame of activity counts and adds a column of time stamps in POSIXct format.
The time stamps start at "2012-04-07 00:00:30" and increase by 30 seconds for each row of the data frame.
Usage
add_date_and_format(counts)
Value
a data frame with time stamps added in POSIXct format
Arguments
- counts
a data frame containing activity counts