powered by
This function generates an activity sequence for a complete day with a minimal activity count.
make_smallest_complete_day_activity(min_complete_day = 8602)
An activity sequence data frame with minimum activity counts for a complete day.
minimum number of epochs for something to be a complete day
make_smallest_complete_day_activity()
Run the code above in your browser using DataLab