Learn R Programming

walkboutr (version 0.6.0)

make_smallest_nonwearing_window: Create smallest non-wearing window

Description

Create an inactive period that represents the smallest non-wearing window. This function uses the make_inactive_period() function to create the non-wearing window.

Usage

make_smallest_nonwearing_window(min_non_wearing_length = 20 * 2)

Value

An inactive period data frame that represents the smallest non-wearing window.

Arguments

min_non_wearing_length

minimum non_wearing time before a bout is terminated

Examples

Run this code
make_smallest_nonwearing_window()

Run the code above in your browser using DataLab