powered by
Create an inactive period that represents the smallest non-wearing window. This function uses the make_inactive_period() function to create the non-wearing window.
make_inactive_period()
make_smallest_nonwearing_window(min_non_wearing_length = 20 * 2)
An inactive period data frame that represents the smallest non-wearing window.
minimum non_wearing time before a bout is terminated
make_smallest_nonwearing_window()
Run the code above in your browser using DataLab