Outlier GPS data points This function identifies outlier GPS points for the bout radius calculation from a given set of latitude and longitude coordinates.
outlier_gps_points(lat_long, dwellbout_radii_quantile)A data frame containing the latitude and longitude coordinates for the non-outlier GPS points.
A data frame containing the latitude and longitude coordinates for the GPS points.
The threshold for outliering GPS data points - any data points above the specified percentile are outliered.