The input schema for the accelerometry data is time, latitude, longitude, and speed.
time should be a column in date-time format, in the UTC time zone, with no null values.
latitude should be a numeric, non-null latitude coordinate between -90 and 90
longitude should be a numeric, non-null longitude coordinate between -180 and 180
speed should be a numeric, non-null value in kilometers per hour
process_gps_data_into_gps_epochs(gps_data, ..., collated_arguments = NULL)A data frame with columns latitude, longitude, time, and speed, where time is now the nearest epoch start time
A data frame containing GPS data. Must have columns "Latitude", "Longitude"
Additional arguments to be passed to the function.
A named list of arguments, used to avoid naming conflicts when calling this function as part of a pipeline. Optional.
This function processes GPS data into GPS epochs, with each epoch having a duration specified by epoch_length.